@@ -1,5 +1,6 @@
 #!/usr/bin/env python3
 
 from squad_client.manage import main
+import sys
 
-main()
+sys.exit(main())
